@@ -10,6 +10,5 @@
 #' @keywords datasets
 #' @examples
 #' plot(canadian)
-#' @export
-
-canadian <- stats::ts(c(5.4, 5.3, 5.3, 5.6, 6.9, 7.2, 7.2),f=4,s=1974)
+#'
+"canadian"
